google_type

package
v0.13.1-0...-264b242 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 13, 2019 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Date

type Date struct {
	// Day of month. Must be from 1 to 31 and valid for the year and month, or 0. if specifying a year by itself or a year and month where the day is not significant.
	Day int32 `protobuf:"varint,3,opt,name=day,proto3" json:"day,omitempty"`
	// Localized String representation of date
	DisplayName string `protobuf:"bytes,4,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Month of year. Must be from 1 to 12, or 0 if specifying a year without a month and day.
	Month int32 `protobuf:"varint,2,opt,name=month,proto3" json:"month,omitempty"`
	// Year of date. Must be from 1 to 9999, or 0 if specifying a date without a year.
	Year                 int32    `protobuf:"varint,1,opt,name=year,proto3" json:"year,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

Date, https://github.com/googleapis/googleapis/blob/master/google/date.proto

func (*Date) Descriptor

func (*Date) Descriptor() ([]byte, []int)

func (*Date) GetDay

func (m *Date) GetDay() int32

func (*Date) GetDisplayName

func (m *Date) GetDisplayName() string

func (*Date) GetMonth

func (m *Date) GetMonth() int32

func (*Date) GetYear

func (m *Date) GetYear() int32

func (*Date) ProtoMessage

func (*Date) ProtoMessage()

func (*Date) Reset

func (m *Date) Reset()

func (*Date) String

func (m *Date) String() string

func (*Date) XXX_DiscardUnknown

func (m *Date) XXX_DiscardUnknown()

func (*Date) XXX_Marshal

func (m *Date) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Date) XXX_Merge

func (m *Date) XXX_Merge(src proto.Message)

func (*Date) XXX_Size

func (m *Date) XXX_Size() int

func (*Date) XXX_Unmarshal

func (m *Date) XXX_Unmarshal(b []byte) error

type Money

type Money struct {
	// The 3-letter currency code defined in ISO 4217.
	CurrencyCode string `protobuf:"bytes,2,opt,name=currency_code,json=currencyCode,proto3" json:"currency_code,omitempty"`
	// String representation of money entity
	DisplayName string `protobuf:"bytes,1,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Number of nano (10^-9) units of the amount. For example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.
	Nanos int64 `protobuf:"varint,4,opt,name=nanos,proto3" json:"nanos,omitempty"`
	// The whole units of the amount.
	Units                int64    `protobuf:"varint,3,opt,name=units,proto3" json:"units,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

Represents an amount of money with its currency type. https://github.com/googleapis/googleapis/blob/master/google/money.proto

func (*Money) Descriptor

func (*Money) Descriptor() ([]byte, []int)

func (*Money) GetCurrencyCode

func (m *Money) GetCurrencyCode() string

func (*Money) GetDisplayName

func (m *Money) GetDisplayName() string

func (*Money) GetNanos

func (m *Money) GetNanos() int64

func (*Money) GetUnits

func (m *Money) GetUnits() int64

func (*Money) ProtoMessage

func (*Money) ProtoMessage()

func (*Money) Reset

func (m *Money) Reset()

func (*Money) String

func (m *Money) String() string

func (*Money) XXX_DiscardUnknown

func (m *Money) XXX_DiscardUnknown()

func (*Money) XXX_Marshal

func (m *Money) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Money) XXX_Merge

func (m *Money) XXX_Merge(src proto.Message)

func (*Money) XXX_Size

func (m *Money) XXX_Size() int

func (*Money) XXX_Unmarshal

func (m *Money) XXX_Unmarshal(b []byte) error

Jump to